@@ -34,7 +34,7 @@ class MQManager(Singleton):
         if not hasattr(self, 'mq'):
             self.mq = await open_connection(self.host, self.port)
         
-        if self.mq.status == 0:
+        if not self.mq.is_connected:
             del self.mq
             return await self.get_mq_conn()
         else:
